@@ -7,7 +7,7 @@ import threading
 
 import requests
 
-__version__ = '1.4.2b'
+__version__ = '1.4.3b'
 
 class Event(object):
 	def __init__(self, connection):
@@ -145,7 +145,7 @@ class Client(object):
 		self.xhr = self.__initialize(self.settings)
 		self.priv_dict = {}
 
-	def login(username, password):
+	def __login(username, password):
 		login_data = {
 			'action': 'login',
 			'lgname': username,
